==> virtualbox-sdk-7.0.2-1-x86_64.pkg.tar.zst: org/virtualbox_7_0/jaxws/IVirtualBoxCheckFirmwarePresent.java <==

package org.virtualbox_7_0.jaxws;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="_this" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="firmwareType" type="{http://www.virtualbox.org/}FirmwareType"/>
 *         &lt;element name="version" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_this",
    "firmwareType",
    "version"
})
@XmlRootElement(name = "IVirtualBox_checkFirmwarePresent")
public class IVirtualBoxCheckFirmwarePresent {

    @XmlElement(required = true)
    protected String _this;
    @XmlElement(required = true)
    @XmlSchemaType(name = "string")
    protected FirmwareType firmwareType;
    @XmlElement(required = true)
    protected String version;

    /**
     * Gets the value of the this property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getThis() {
        return _this;
    }

    /**
     * Sets the value of the this property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setThis(String value) {
        this._this = value;
    }

    /**
     * Gets the value of the firmwareType property.
     * 
     * @return
     *     possible object is
     *     {@link FirmwareType }
     *     
     */
    public FirmwareType getFirmwareType() {
        return firmwareType;
    }

    /**
     * Sets the value of the firmwareType property.
     * 
     * @param value
     *     allowed object is
     *     {@link FirmwareType }
     *     
     */
    public void setFirmwareType(FirmwareType value) {
        this.firmwareType = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        return version;
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}

==> virtualbox-sdk-7.1.12-1-x86_64.pkg.tar.zst: org/virtualbox_7_1/jaxws/IVirtualBoxCheckFirmwarePresent.java <==

package org.virtualbox_7_1.jaxws;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="_this" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="platformArchitecture" type="{http://www.virtualbox.org/}PlatformArchitecture"/>
 *         &lt;element name="firmwareType" type="{http://www.virtualbox.org/}FirmwareType"/>
 *         &lt;element name="version" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_this",
    "platformArchitecture",
    "firmwareType",
    "version"
})
@XmlRootElement(name = "IVirtualBox_checkFirmwarePresent")
public class IVirtualBoxCheckFirmwarePresent {

    @XmlElement(required = true)
    protected String _this;
    @XmlElement(required = true)
    @XmlSchemaType(name = "string")
    protected PlatformArchitecture platformArchitecture;
    @XmlElement(required = true)
    @XmlSchemaType(name = "string")
    protected FirmwareType firmwareType;
    @XmlElement(required = true)
    protected String version;

    /**
     * Gets the value of the this property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getThis() {
        return _this;
    }

    /**
     * Sets the value of the this property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setThis(String value) {
        this._this = value;
    }

    /**
     * Gets the value of the platformArchitecture property.
     * 
     * @return
     *     possible object is
     *     {@link PlatformArchitecture }
     *     
     */
    public PlatformArchitecture getPlatformArchitecture() {
        return platformArchitecture;
    }

    /**
     * Sets the value of the platformArchitecture property.
     * 
     * @param value
     *     allowed object is
     *     {@link PlatformArchitecture }
     *     
     */
    public void setPlatformArchitecture(PlatformArchitecture value) {
        this.platformArchitecture = value;
    }

    /**
     * Gets the value of the firmwareType property.
     * 
     * @return
     *     possible object is
     *     {@link FirmwareType }
     *     
     */
    public FirmwareType getFirmwareType() {
        return firmwareType;
    }

    /**
     * Sets the value of the firmwareType property.
     * 
     * @param value
     *     allowed object is
     *     {@link FirmwareType }
     *     
     */
    public void setFirmwareType(FirmwareType value) {
        this.firmwareType = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        return version;
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}
